<?php
/**
 * Child functions file
 *
 * PHP version 7
 *
 * @category WordPress_Theme
 * @package  ThemeCustomization
 *
 * @author  WProDevs <info@wprodevs.com>
 * @license https://www.gnu.org/licenses/gpl-2.0.html GPLv2 or later
 *
 * @link none
 */

/**
 * Enqueue stylesheets
 *
 * @return none
 */
function theme_enqueue_styles()
{
    wp_enqueue_style('child-fonts', get_stylesheet_directory_uri() . '/css/fonts.min.css', ['avada-stylesheet']);
    wp_enqueue_style('child-style', get_stylesheet_directory_uri() . '/style.css', ['child-fonts']);
}
add_action('wp_enqueue_scripts', 'theme_enqueue_styles');

/**
 * Setup for localization
 *
 * @return none
 */
function avada_lang_setup()
{
    $lang = get_stylesheet_directory() . '/languages';
    load_child_theme_textdomain('Avada', $lang);
}
add_action('after_setup_theme', 'avada_lang_setup');

/**
 * Add shims and polyfills for HTML, ES5 and ES6.
 * It is important that it is added on top of every other script
 *
 * @return none
 */
function include_es_shims_in_header_func()
{
    ?>
    <!--[if lte IE 8]>
        <script src="//cdnjs.cloudflare.com/ajax/libs/selectivizr/1.0.2/selectivizr-min.js" defer async></script>
    <![endif]-->
    <!--[if lt IE 9]>
        <script src="//cdnjs.cloudflare.com/ajax/libs/html5shiv/3.7.3/html5shiv-printshiv.min.js" defer async></script>
        <script src="//cdnjs.cloudflare.com/ajax/libs/html5shiv/3.7.3/html5shiv.min.js" defer async></script>
    <![endif]-->
    <script src="//cdn.polyfill.io/v2/polyfill.min.js?features=es5,es6,Promise,Promise.prototype.finally,fetch,Event,Object.entries&amp;flags=always,gated&amp;rum=1"></script>
    <?php
}
add_action('wp_head', 'include_es_shims_in_header_func', 1);

/**
 * Call newsletter sidebar in footer
 *
 * @return none
 */
function show_newsletter_form_in_footer()
{
    echo '<section class="footer-newsletter-container">';
    dynamic_sidebar('Above Footer');
    echo '</section>';
}
add_action('avada_after_main_container', 'show_newsletter_form_in_footer');

/**
 * Customization begins here, using separate classes for different customizations
 *
 * @author WProDevs <info@wprodevs.com>
 */

/**
 * Instantiate different customization classes
 *
 * @return none
 */
function initialize_customization_classes()
{
    include get_stylesheet_directory() . '/includes/classes/autoloader.php';
    \WooCommerce\WooCommerceCustomization::getInstance();
}
add_action('after_setup_theme', 'initialize_customization_classes');

add_filter( 'woocommerce_redirect_single_search_result', '__return_false' );
