<?php
/**
 * This file is contains some useful functions
 *
 * PHP version 7
 *
 * @category WordPress_Theme
 * @package  ThemeCustomization
 *
 * @author  WProDevs <info@wprodevs.com>
 * @license https://www.gnu.org/licenses/gpl-3.0.html GPLv3 or later
 *
 * @link none
 */

namespace WooCommerce\Traits;

/**
 * This trait is used to store helper functions
 *
 * @category WordPress_Theme
 * @package  ThemeCustomization
 *
 * @author  WProDevs <info@wprodevs.com>
 * @license https://www.gnu.org/licenses/gpl-3.0.html GPLv3 or later
 *
 * @link none
 */
trait HelperFunctions
{
    /**
     * Prints or returns specified template file
     *
     * @param string     $template            Template file name to load
     * @param bool       $return              Whether to return template content or echo them
     * @param array|null $addition_paremeters Variable to be shared with that template
     *
     * @return string|none
     */
    private function _getTemplate($template, $return = true, $addition_paremeters = null)
    {
        $template_path = get_stylesheet_directory() . "/includes/templates/{$template}";
        if (!file_exists($template_path)) {
            $error = new \WP_Error();
            $error->add('wpro-wc', 'Template file is missing');

            return $error;
        }
        if (null !== $addition_paremeters) {
            extract($addition_paremeters, EXTR_SKIP);
        }

        ob_start();
        include_once $template_path;
        $content = ob_get_clean();
        if ($return) {
            return $content;
        }
        echo $content;
    }
}